@@ -19,7 +19,7 @@ add_section_heading_line <- function(
 
     heading <-
       stringi::stri_c(strrep("#", times = level), " ", heading,
-                      "{#sec-", conv_to_valid_obj_name(value), "_",
+                      "{#sec-", conv_to_valid_obj_name(value), "-",
                       stringi::stri_c(sample(0:9, size=2, replace = TRUE), ignore_null=TRUE, collapse=""),
                       "}\n",
                       ignore_null=TRUE)
