@@ -4,7 +4,7 @@ remove_empty_col_for_mesos_group <- function(data,
                                              mesos_var,
                                              log_file = NULL,
                                              hide_result_if_n_below = 10) {
-  if(rlang::is_string(mesos_group)) {
+  if(is_string(mesos_group)) {
     unique_vars <- unique(c(as.character(chapter_overview$.variable_name_dep),
                             as.character(chapter_overview$.variable_name_indep)))
     unique_vars <- unique_vars[!is.na(unique_vars)]
@@ -18,7 +18,7 @@ remove_empty_col_for_mesos_group <- function(data,
          !is.character(tmp[[var]])) {
         msg <- "In mesos_group {mesos_group}, removing empty column {var}."
         cli::cli_inform(msg)
-        if(rlang::is_string(log_file)) {
+        if(is_string(log_file)) {
           cli::cat_print(x = paste0(msg, "\n"), file = log_file)
         }
         chapter_overview <- vctrs::vec_slice(chapter_overview,
