@@ -1,4 +1,4 @@
-test_that("ungroup_data", {
+testthat::test_that("ungroup_data", {
   x <- saros::ex_survey %>%
     dplyr::group_by(.data$f_uni)
   testthat::expect_false(inherits(saros:::ungroup_data(x), "grouped_df"))
